@@ -406,15 +406,12 @@ def theme_url
 end
 
 def css_tag
+	location, name = (@conf.theme || '').split(%r[/], 2)
 	if @mode =~ /conf$/ then
 		css = "#{h theme_url}/conf.css"
-	elsif @conf.theme and @conf.theme.length > 0
-		location, name = @conf.theme.split(/\//, 2)
-		unless name
-			name = location
-			location = 'local'
-		end
+	elsif name && name.length > 0
 		css = __send__("theme_url_#{location}", name)
+		css = theme_url_local('default') unless css # the location is not defined
 	else
 		css = @conf.css
 	end
@@ -830,8 +827,7 @@ def conf_theme_list
 end
 
 def theme_list_local(list)
-	theme_paths = [::TDiary::PATH, TDiary.server_root].map {|d| "#{d}/theme/*" }
-	Dir::glob( theme_paths ).sort.map {|dir|
+	Dir::glob( theme_paths_local ).sort.map {|dir|
 		theme = dir.sub( %r[.*/theme/], '')
 		next unless FileTest::file?( "#{dir}/#{theme}.css".untaint )
 		name = theme.split( /_/ ).collect{|s| s.capitalize}.join( ' ' )
@@ -844,6 +840,10 @@ def theme_url_local(theme)
 	"#{h theme_url}/#{h theme}/#{h theme}.css"
 end
 
+def theme_paths_local
+	[::TDiary::PATH, TDiary.server_root].map {|d| "#{d}/theme/*" }
+end
+
 def saveconf_theme
 	if @mode == 'saveconf' then
 		@conf.theme = @cgi.params['theme'][0]
@@ -974,7 +974,7 @@ def saveconf_recommendfilter
 		@conf['spamfilter.max_uris'] = "1"
 		@conf['spamfilter.resolv_check'] = true
 		@conf['spamfilter.resolv_check_mode'] = false
-		@conf['spamlookup.domain.list'] = "bsb.spamlookup.net\r\nsc.surbl.org\r\nrbl.bulkfeeds.jp"
+		@conf['spamlookup.domain.list'] = "bsb.spamlookup.net\r\nmulti.surbl.org\r\nrbl.bulkfeeds.jp"
 		@conf['spamlookup.ip.list'] = "dnsbl.spam-champuru.livedoor.com"
 		@conf['spamlookup.safe_domain.list'] = "www.google.com\r\nwww.google.co.jp\r\nezsch.ezweb.ne.jp\r\nwww.yahoo.co.jp\r\nsearch.mobile.yahoo.co.jp\r\nwww.bing.com"
 	end
