@@ -28,8 +28,7 @@
   URLは１つのカテゴリーしか持てないことにご注意ください。-))
 * 基本的な設定をWWWブラウザからできるようになった
 * disp_referrer.rbが無くても使える
-* UconvライブラリやNoraライブラリがあればあるなりに、無ければないなりに
-  動作する
+* Uconvライブラリがあればあるなりに、無ければないなりに動作する
 という利点があります。
 
 == 使い方
@@ -105,13 +104,6 @@ mod_rubyでの動作は今のところ確認していません。
 ((<URL:http://zunda.freeshell.org/d/plugin/disp_referrer2.rb>))
 にあるはずです。
 
-また、Noraライブラリがインストールされている場合には、URLの解釈やHTMLの
-エスケープに、Rubyに標準添付のCGIライブラリの代わりにNoraライブラリを使
-用します。これにより、処理速度が若干速くなります((-手元で試したところ、
-一日分の表示にかかる時間が1割程度短かくなりました。-))。Noraについての詳
-細は、((<URL:http://raa.ruby-lang.org/list.rhtml?name=Nora>))を参照して
-ください。
-
 === オプション
 この日記で設定できるオプションの一覧は、DispRef2Setup::Defaultsにありま
 す。これらのオプションのkeyの最初に、「disp_referrer2.」を追加すること
